@@ -5,7 +5,7 @@
  * Author:   Georg Fleischmann
  *
  * created:  1996-01-29
- * modified: 2005-04-25 (clean up)
+ * modified: 2005-09-03 (-hitControl)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -2221,6 +2221,7 @@ static int intersectCurves(NSPoint pc1[4], const NSPoint pc2[4], NSPoint *points
 /*
  * Check for a control point hit.
  * Return the point number hit in the pt_num argument.
+ * modified: 2005-09-03
  */
 - (BOOL)hitControl:(NSPoint)p :(int *)pt_num controlSize:(float)controlsize
 {   int		i;
@@ -2228,6 +2229,7 @@ static int intersectCurves(NSPoint pc1[4], const NSPoint pc2[4], NSPoint *points
     float	lastDist = LARGE_COORD, dist;
     BOOL	hit = NO;
 
+    *pt_num = 0; // if p0==p1 or p3==p2 we take p0 or p3 !
     knobRect.size.width = knobRect.size.height = controlsize;
     for (i=0; i < PTS_BEZIER*2; i += 2)
     {
@@ -2236,7 +2238,9 @@ static int intersectCurves(NSPoint pc1[4], const NSPoint pc2[4], NSPoint *points
         if ( NSPointInRect(p, knobRect) )
         {
             dist = SqrDistPoints(NSMakePoint(path.pts[i+4], path.pts[i+5]), p);
-            if ( dist < lastDist )
+            /* if p0==p1 or p3==p2 we take p0, p3 */
+            if ( (dist < lastDist && !(*pt_num)) || (dist <= lastDist && *pt_num) )
+            //if ( dist < lastDist )
             {
                 lastDist = dist;
                 *pt_num = i/2;
