@@ -1,11 +1,11 @@
 /* VMark.m
  * Drill marker or any other marking
  *
- * Copyright (C) 1996-2004 by vhf interservice GmbH
+ * Copyright (C) 1996-2005 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * created:  1997-11-13
- * modified: 2004-10-31
+ * modified: 2005-08-21
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -66,7 +66,7 @@
 }
 
 /*
- * created: 25.09.95
+ * created:  1995-09-25
  * purpose: initializes all the stuff needed after a -read:
  */
 - (void)setParameter
@@ -176,7 +176,8 @@
  * draws the mark
  */
 - (void)drawWithPrincipal:principal
-{   float	radius = 5.0;
+{   float	radius = 5.0;	// FIXME: shouldn't there exist a mode to display the diameter ???
+    //float	radius = (displayDia) ? MMToInternal(diameter) : 5.0;
 
     [super drawWithPrincipal:principal];	// color
     [NSBezierPath setDefaultLineWidth:0.0];
