@@ -5,7 +5,7 @@
  * Author:   Georg Fleischmann
  *
  * created:  1996-09-17
- * modified: 2005-04-25 (clean up)
+ * modified: 2005-09-08
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -637,7 +637,7 @@
                 [self setColor:sepColor];
             }
             [super drawWithPrincipal:principal];	// set color
-            [NSBezierPath strokeRect:NSMakeRect(origin.x, origin.y, Max( 1.0, size.x), Max( 1.0, size.y))];
+            [NSBezierPath strokeRect:NSMakeRect(origin.x, origin.y, Max( 0.01, size.x), Max( 0.01, size.y))];
 
             if (!VHFIsDrawingToScreen() && [principal separationColor])
             {   [self setColor:oldColor];
@@ -1307,26 +1307,6 @@
             [splitListUg addObject:[[ug copy] autorelease]];
     }
 
-    /* ug is'nt a path and not splitted now there are two possibilities
-     * self is in ug or ug is in self else -> nothing to unite - NO
-     */
-    if ( ![ug isKindOfClass:[VPath class]] && [splitListUg count] == 1 && ![ug isKindOfClass:[VGroup class]])
-    {	NSPoint	p;
-
-        [pool release];
-        /* ug is inside self -> self is ok can remove ug later */
-        ( [ug isKindOfClass:[VPath class]] ) ? [[[(VPath*)ug list] objectAtIndex:0] getPoint:&p at:0.4] :
-            [ug getPoint:&p at:0.4];
-        if ( [self isPointInside:p] )
-            return [[self copy] autorelease];
-
-        /* self is inside ug -> ug is it */
-        [self getPoint:&p at:0.4];
-        if ( [(id)ug isPointInside:p] )
-            return [[ug copy] autorelease];
-        return NO;	/* nothing to unite */
-    }
-
     /* get startIndexes from splitListUg */
     uStartIsCnt = 1;
     uStartIs[0] = 0;
@@ -1336,18 +1316,26 @@
         VGraphic	*sg = [splitListUg objectAtIndex:uStartIs[uStartIsCnt-1]];
 
         endIx = -1;
+
         startPt = [sg pointWithNum:0];
         for ( i=uStartIs[uStartIsCnt-1]; i < uListCnt; i++ )
         {
             e = [[splitListUg objectAtIndex:i] pointWithNum:MAXINT];
             if ( SqrDistPoints(startPt, e) < tol*tol )
-            {   endIx = i;
+            {
+                if (i+1 < uListCnt)
+                {   NSPoint	begN = [[splitListUg objectAtIndex:i+1] pointWithNum:0];
+
+                    if ( SqrDistPoints(e, begN) < (TOLERANCE*15)*(TOLERANCE*15) )
+                        continue; // dist to next gr is smaller !
+                }
+                endIx = i;
                 break;
             }
         }
         if (endIx == -1)
         {   uStartIs[uStartIsCnt++] = uListCnt-1;
-            NSLog(@"VPath.m: -uniteWith: endIx not found !");
+            NSLog(@"VRectangle.m: -uniteWith: endIx not found !");
             break;
         }
         else
@@ -1488,7 +1476,7 @@
                                 startIs[l] = startIs[l+2];
                             }
                             sCnt--; // we remove two points !
-//                            NSLog(@"VPath.m: -uniteWith: one startPt pair was currently removed");
+//                            NSLog(@"VRectangle.m: -uniteWith: one startPt pair was currently removed");
                         }
                         else if (spCnt > 1 && i == startIs[si0+1])
                         {
@@ -1527,8 +1515,8 @@
             listCnt--;
         }
         /* close gap with graphics from splitListUg */
-        if ((!currentlyRemoved && removing == YES)
-            || (removing == YES && !first && i+1 == startI)) // than we must fill the gap also with/from ug
+        if ((!currentlyRemoved && removing == YES) // i+1
+            || (removing == YES && !first && ((i+1 >= listCnt) ? (0) : (i+1)) == startI)) // last endpts to start gr
         {   NSPoint	s;
 
             /* search nextG for endPts[1]   no nextG found - startG == endG - only one Graphic ! */
@@ -1542,6 +1530,28 @@
             else // currentlyRemoved -> i perhaps -1
             {   int	l, nextI = ((i+1 >= listCnt) ? 0 : i+1);
 
+                /* correct endIs[eCnt-1] !!! - we remove the last graphic in list to startI */
+                if (i+1 >= listCnt) // endIs[eCnt-1]++ ! - nextI wird i+2 !
+                {
+                    /* we have to correct only the index !!! */
+                    for (l=nextI; l != ((i < 0) ? (listCnt-1) : i); l++)
+                    {   VGraphic	*gr = [[ng list] objectAtIndex:l];
+                        
+                    // if (k == i) break; // one time around
+                        s = [gr pointWithNum:0];
+                        if (SqrDistPoints(s, endPts[eCnt-1]) <= tol*tol) // nextG found
+                        {   //NSPoint	e = [gr pointWithNum:MAXINT];
+
+                            endIs[eCnt-1] = l;
+                            //endPts[eCnt-1] = e;
+                            break;
+                        }
+                        if (l == listCnt-1)
+                            l = -1; // go around until i !
+                    }
+                   //nextI = ((nextI+1 >= listCnt) ? 0 : nextI+1);
+                }
+
                 for (l=nextI; l != ((i < 0) ? (listCnt-1) : i); l++)
                 {   VGraphic	*gr = [[ng list] objectAtIndex:l];
                     
@@ -1583,6 +1593,17 @@
                 }
             }
         }
+        /* we must check if we remove a hole subpath */
+        for (i=0; i< uStartIsCnt-1; i++)
+        {
+            if (uStartIs[i] == uStartIs[i+1])
+            {
+                for (l=i; l < uStartIsCnt-1; l++)
+                    uStartIs[l] = uStartIs[l+1];
+                uStartIsCnt--;
+                i--; // perhaps we remove two or three
+            }
+        }
         if (![splitListUg count])
         {   [pool release];
             return ng;
@@ -1591,6 +1612,25 @@
 
     if (!removedFromNg && !removedFromUg)
     {
+        /* ug is'nt a path and not splitted now there are two possibilities
+        * self is in ug or ug is in self else -> nothing to unite - NO
+        */
+        if ( ![ug isKindOfClass:[VPath class]] && [splitListUg count] == 1 && ![ug isKindOfClass:[VGroup class]])
+        {	NSPoint	p;
+
+            [pool release];
+            /* ug is inside self -> self is ok can remove ug later */
+            ( [ug isKindOfClass:[VPath class]] ) ? [[[(VPath*)ug list] objectAtIndex:0] getPoint:&p at:0.4] :
+                [ug getPoint:&p at:0.4];
+            if ( [self isPointInside:p] )
+                return [[self copy] autorelease];
+
+            /* self is inside ug -> ug is it */
+            [self getPoint:&p at:0.4];
+            if ( [(id)ug isPointInside:p] )
+                return [[ug copy] autorelease];
+            return NO;	/* nothing to unite */
+        }
         [pool release];
         return NO;
     }
@@ -1873,7 +1913,8 @@
                     }
                 }
                 if (closeK != -1)
-                {   int	added = 0, from = closeK, to = j;
+                {   int		added = 0, from = closeK, to = j;
+                    float	dist = MAXCOORD;
 
                     /* get endI, eptCnt and eI0 */
                     if (pointWithToleranceInArray(closePt, tol, endPts, eCnt))
@@ -1885,7 +1926,7 @@
                             }
                     }
                     else
-                        NSLog(@"VPath.m: -uniteWith: this should be not possible");
+                        NSLog(@"VRectangle.m: -uniteWith: this should be not possible");
 
                     eI0 = 0;
                     for (k=0; k < ePairsCnt; k++)
@@ -1911,7 +1952,8 @@
                     /* if eCnt/sCnt > 1
                     * && ej/sj... gleich zu ..Pts[1] -> ..Is[0] aus [ng list] removen !!!!!!!!!! */
                     if (sptCnt > 1 &&
-                        (SqrDistPoints(ej, sPts[1]) < tol*tol || SqrDistPoints(sj, sPts[1]) < tol*tol) &&
+                        (((dist=SqrDistPoints(ej, sPts[1])) < tol*tol && dist < SqrDistPoints(ej, sPts[0])) ||
+                         ((dist=SqrDistPoints(sj, sPts[1])) < tol*tol && dist < SqrDistPoints(sj, sPts[0]))) &&
                         !pointWithToleranceInArray(sPts[1], tol, endPts, eCnt))
                     {   /* remove object at sIs[0] from [ng list] */
                         [[ng list] removeObjectAtIndex:sIs[0]];
@@ -1928,8 +1970,10 @@
                         listCnt--;
                     }
 
-                    if ((eptCnt > 1 && (SqrDistPoints(closePt, ePts[1]) < tol*tol &&
-                                        !pointWithToleranceInArray(ePts[1], tol, startPts, sCnt)))
+                    if ((eptCnt > 1 &&
+                         ((dist=SqrDistPoints(closePt, ePts[1])) < tol*tol &&
+                          dist < SqrDistPoints(closePt, ePts[0]) && // tol*tol
+                          !pointWithToleranceInArray(ePts[1], tol, startPts, sCnt)))
                         || (jumpOverOneEnd && eptCnt > 1 && SqrDistPoints(closePt, ePts[0]) < tol*tol))
                     {	int	ri = eIs[0];
 
@@ -1941,7 +1985,7 @@
                                 ri = -1; // nothing to remove
                             else
                             {   ri = -1;
-                                NSLog(@"VPAth.m -uniteWith: not yet implemented");
+                                NSLog(@"VRectangle.m -uniteWith: not yet implemented");
                             }
                         }
                         if (ri != -1)
@@ -2031,18 +2075,18 @@
     }
 
     /* add closed chapes from splitListUg to ng */
-    if (uStartIsCnt > 1)
+    if (uStartIsCnt > 1 && [splitListUg count])
     {
         for (i=0; i<uStartIsCnt-1; i++)
         {
-            if (uStartIs[i+1]-1 == uStartIs[i]) // only one object
+            if (uStartIs[i+1]-1 == uStartIs[i] && [splitListUg count] == 1) // only one object
             {   VGraphic	*g = [splitListUg objectAtIndex:uStartIs[i]];
 
                 if ([g isKindOfClass:[VArc class]] && Abs([(VArc*)g angle]) == 360.0)
                     [[ng list] addObject:[splitListUg objectAtIndex:j]];
                 continue;
             }
-            else
+            else if ([splitListUg count] >= uStartIs[i+1]-1)
             {   VGraphic	*gs = [splitListUg objectAtIndex:uStartIs[i]];
                 VGraphic	*ge = [splitListUg objectAtIndex:uStartIs[i+1]-1];
                 NSPoint		s, e;
