@@ -5,7 +5,7 @@
  * Author:   Georg Fleischmann
  *
  * created:  1996-02-15
- * modified: 2005-06-10 (setColor...)
+ * modified: 2005-09-01 (replaceSubstring:withString:)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -345,7 +345,6 @@ static void initClassVars()
             [self kernToFitHorizontal];
     }
 }
-
 - (void)replaceCharactersInRange:(NSRange)range withString:(NSString*)string
 {
     if (string)
@@ -356,6 +355,21 @@ static void initClassVars()
             [self kernToFitHorizontal];
     }
 }
+/* created: 2005-09-01
+ */
+- (void)replaceSubstring:(NSString*)substring withString:(NSString*)string
+{
+    if (string)
+    {   NSRange	range = [[attributedString string] rangeOfString:substring];
+
+        if (range.length)
+        {   [self makeMutableAttributedString];
+            [attributedString replaceCharactersInRange:range withString:string];
+            if ( [self fitHorizontal] )
+                [self kernToFitHorizontal];
+        }
+    }
+}
 
 - (void)makeMutableAttributedString
 {
@@ -1674,7 +1688,7 @@ static void initClassVars()
                 [pathG setFillColor:[[[list objectAtIndex:i]fillColor]
                                      colorUsingColorSpaceName:NSDeviceCMYKColorSpace]];
             if (cnt>1)
-                [[group list] addObject:pathG];
+                [group addObject:pathG];	 //[[group list] addObject:pathG];
         }
         if ( !pathG )
             pathG = [VPath path];
