@@ -1,11 +1,11 @@
 /* LayerObject.h
  * Object managing a single layer and its attributes
  *
- * Copyright (C) 1996-2004 by vhf interservice GmbH
+ * Copyright (C) 1996-2005 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * Created:  1996-03-07
- * Modified: 2004-10-23
+ * Modified: 2005-09-01 (LAYER_PAGE, LAYER_TEMPLATE* added)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -45,14 +45,21 @@ typedef struct
 #define CUT_BLOWUP	5	// calculate blow up of PCB
 #define CUT_RUBOUT	6	// calculate rubout of PCB
 
-/* these shouldn't be changed, they are saved to the document !
+/* the layer ids shouldn't be changed, they are saved to the document !
  */
-#define LAYER_STANDARD	0	// standard layer
-#define LAYER_PASSIVE	1
-#define LAYER_CLIPPING	2
-#define LAYER_LEVELING	3
-#define LAYER_FITTING	4	// a layer with two marks for flipping the working piece
-//#define LAYER_PAGE	5	// page in multi page document
+typedef enum
+{
+    LAYER_STANDARD   = 0,	// standard layer
+    LAYER_PASSIVE    = 1,	// passive layer, not editable, calculated automatically (CAM)
+    LAYER_CLIPPING   = 2,	// layer with regions used for clipping (CAM)
+    LAYER_LEVELING   = 3,	// layer with elements defining an area for leveling (CAM)
+    LAYER_FITTING    = 4,	// a layer with two marks for flipping the working piece (CAM)
+    LAYER_PAGE       = 5,	// page in multi page document
+
+    LAYER_TEMPLATE   = 10,	// general template for all layers and pages
+    LAYER_TEMPLATE_1 = 11,	// template for odd pages
+    LAYER_TEMPLATE_2 = 12	// template for even pages
+} LayerType;
 
 @interface LayerObject: NSObject
 {
@@ -68,7 +75,7 @@ typedef struct
     BOOL		useForTile;		// whether layer is used for duplicates
     BOOL		dirty;			// YES when changed
 
-    /* CAM */
+    /* CAM (should move to a sub class) */
     int			toolIndex;		// the index of the tool
     NSString		*toolString;		// the name of the tool
     BOOL		filled;			// whether we are filled
@@ -150,7 +157,7 @@ typedef struct
 - (void)setLikeOtherLayers:(BOOL)flag;
 
 
-/* CAM */
+/* CAM (should be moved to a sub class) */
 - (void)setToolIndex:(int)aTool;
 - (int)toolIndex;
 - (void)setToolString:(NSString*)theToolString;
